==> jc-1.4.0.tar.gz: gnu/xml/libxmlj/dom/GnomeDOMException.h <==
// class gnu.xml.libxmlj.dom.GnomeDOMException

// class file dependencies
// @dep_class 4a113a71b8375285 gnu_xml_libxmlj_dom_GnomeDOMException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class ca80c12995054194 org_w3c_dom_DOMException

// header file dependencies
// @dep_header org_w3c_dom_DOMException

#include "org/w3c/dom/DOMException.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeDOMException_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeDOMException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeDOMException$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeDOMException$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$refs	_jc_gnu_xml_libxmlj_dom_GnomeDOMException$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeDOMException$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$object	_jc_gnu_xml_libxmlj_dom_GnomeDOMException$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeDOMException$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$vtable	_jc_gnu_xml_libxmlj_dom_GnomeDOMException$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$vtype	_jc_gnu_xml_libxmlj_dom_GnomeDOMException$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeDOMException$method$_init$f5cdf9de5128930c(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$object *, jshort, struct _jc_java_lang_String$object *);

// Static methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeDOMException$method$createMessage$6cf2dd749f38b611(_jc_env *, jint, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$vmethods {
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_org_w3c_dom_DOMException$vmethods	org_w3c_dom_DOMException;
	_jc_gnu_xml_libxmlj_dom_GnomeDOMException$vmethods	gnu_xml_libxmlj_dom_GnomeDOMException;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeDOMException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeDOMException$sub_refs	gnu_xml_libxmlj_dom_GnomeDOMException;
    _jc_org_w3c_dom_DOMException$sub_refs	org_w3c_dom_DOMException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_org_w3c_dom_DOMException$sub_nonrefs	org_w3c_dom_DOMException;
    _jc_gnu_xml_libxmlj_dom_GnomeDOMException$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeDOMException;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$object {
	_jc_gnu_xml_libxmlj_dom_GnomeDOMException$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeDOMException$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeDOMException$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeDOMException$vtype _jc_gnu_xml_libxmlj_dom_GnomeDOMException$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeDOMException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeDOMException$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeDOMException_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/libxmlj/dom/GnomeDOMException.h <==
// class gnu.xml.libxmlj.dom.GnomeDOMException

// class file dependencies
// @dep_class 4a113a71b8375285 gnu_xml_libxmlj_dom_GnomeDOMException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class ca80c12995054194 org_w3c_dom_DOMException

// header file dependencies
// @dep_header org_w3c_dom_DOMException

#include "org/w3c/dom/DOMException.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeDOMException_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeDOMException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeDOMException$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeDOMException$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$refs	_jc_gnu_xml_libxmlj_dom_GnomeDOMException$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeDOMException$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$object	_jc_gnu_xml_libxmlj_dom_GnomeDOMException$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeDOMException$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$vtable	_jc_gnu_xml_libxmlj_dom_GnomeDOMException$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$vtype	_jc_gnu_xml_libxmlj_dom_GnomeDOMException$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeDOMException$method$_init$f5cdf9de5128930c(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$object *, jshort, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeDOMException$method$createMessage$6cf2dd749f38b611(_jc_env *, jint, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$vmethods {
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_org_w3c_dom_DOMException$vmethods	org_w3c_dom_DOMException;
	_jc_gnu_xml_libxmlj_dom_GnomeDOMException$vmethods	gnu_xml_libxmlj_dom_GnomeDOMException;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeDOMException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeDOMException$sub_refs	gnu_xml_libxmlj_dom_GnomeDOMException;
    _jc_org_w3c_dom_DOMException$sub_refs	org_w3c_dom_DOMException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_org_w3c_dom_DOMException$sub_nonrefs	org_w3c_dom_DOMException;
    _jc_gnu_xml_libxmlj_dom_GnomeDOMException$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeDOMException;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeDOMException$object {
	_jc_gnu_xml_libxmlj_dom_GnomeDOMException$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeDOMException$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeDOMException$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeDOMException$vtype _jc_gnu_xml_libxmlj_dom_GnomeDOMException$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeDOMException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeDOMException$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeDOMException_H_ */
